@@ -49,6 +49,11 @@ class Rates:
         self._reading = reading
         self._address = address
         self._data = None
+        self._redact = [
+            self._api,
+            self._address,
+        ]
+        self._timestamp = datetime.datetime(1990, 1, 1, 0, 0, 0)
 
     def lookup_plans(self) -> Dict[str, Any]:
         """Return the rate plan names per utility in the area."""
@@ -70,8 +75,13 @@ class Rates:
             url = f"{url}&address={self._address}"
 
         rate_names: Dict[str, Any] = {}
-
-        _LOGGER.debug("Looking up plans via URL: %s", url)
+        msg = url
+        for redact in self._redact:
+            if redact:
+                msg = msg.replace(str(redact), "[REDACTED]")
+        redact_msg = "&lat=[REDACTED]&lon=[REDACTED]"
+        msg = msg.replace(f"&lat={self._lat}&lon={self._lon}", redact_msg)
+        _LOGGER.debug("Looking up plans via URL: %s", msg)
 
         result = requests.get(url)
         if result.status_code == 404:
@@ -97,11 +107,29 @@ class Rates:
         return rate_names
 
     def update(self) -> None:
+        """Update data only if we need to."""
+        if self._data is None:
+            _LOGGER.debug("No data populated, refreshing data.")
+            self.update_data()
+            self._timestamp = datetime.datetime.now()
+        else:
+            elapsedtime = datetime.datetime.now() - self._timestamp
+            past = datetime.timedelta(hours=24)
+            if elapsedtime >= past:
+                _LOGGER.debug("Data stale, refreshing from API.")
+                self.update_data()
+                self._timestamp = datetime.datetime.now()
+
+    def update_data(self) -> None:
         """Update the data."""
         url = f"{BASE_URL}version=latest&format=json&detail=full"
         url = f"{url}&api_key={self._api}&getpage={self._plan}"
 
-        _LOGGER.debug("Updating data via URL: %s", url)
+        msg = url
+        for redact in self._redact:
+            if redact:
+                msg = msg.replace(str(redact), "[REDACTED]")
+        _LOGGER.debug("Updating data via URL: %s", msg)
 
         result = requests.get(url)
         if result.status_code == 404:
